export default class Segment {
  constructor () {
    this.allCountries = [
      { text: 'Lebanon', value: 'Lebanon' },
      { text: 'United Arab Emirates', value: 'United Arab Emirates' },
      { text: 'Saudi Arabia', value: 'Saudi Arabia' },
      { text: 'Kuwait', value: 'Kuwait' },
      { text: 'Morocco', value: 'Morocco' },
      { text: 'Egypt', value: 'Egypt' },
      { text: 'Iraq', value: 'Iraq' },
      { text: 'Bahrain', value: 'Bahrain' },
      { text: 'Oman', value: 'Oman' },
      { text: 'Jordan', value: 'Jordan' },
      { text: 'Qatar', value: 'Qatar' },
      { text: 'Tunisia', value: 'Tunisia' },
      { text: 'Algeria', value: 'Algeria' },
      { text: 'Turkey', value: 'Turkey' },
      { text: 'MENA region', value: 'MENA region' }
    ]
    this.selectedCountries = []
    this.selectedCountry = ''
    this.interests = [
      { text: 'Beauty', value: 'f34efb49-4514-4c44-8d4a-dcc842cd6b3d' },
      { text: 'Fashion Accessories', value: 'dc1511d3-9059-4368-85a4-6a080cb2aaa1' },
      { text: 'Technology', value: 'e7fbb705-fb20-4663-89c4-2ccfc158c4fb' },
      { text: 'Travel', value: '613c88e7-7466-4563-85bb-b9c6255457c8' },
      { text: 'Automobiles', value: 'b1b70c30-0d13-4940-9877-4298991dbf58' },
      { text: 'Fitness & Wellness', value: '59e7c452-4f0d-46bf-9ef9-840444c6397e' },
      { text: 'Sports & Outdoors', value: '0c126ef4-e497-4b05-8aaa-4a81aefc4c7e' },
      { text: 'Family & Relationships', value: '56ca9849-939c-4272-a2fc-59a5368fe32c' },
      { text: 'Food & Drink', value: '7c836322-6cd9-4521-b947-ca59a2a5de1f' }
    ]
    this.selectedInterest = null
    this.selectedAgeRanges = []
    this.selectedGenders = []
    this.selectedPlatforms = []
    this.is1317Selected = false
    this.is1824Selected = false
    this.is2534Selected = false
    this.is3544Selected = false
    this.is4554Selected = false
    this.is5564Selected = false
    this.isAbove65Selected = false
    this.itemSelectedClass = 'item-selected'
    this.itemNormalClass = 'item-normal'
    this.isMaleSelected = false
    this.isFemaleSelected = false
    this.isFacebookSelected = true
    this.isInstagramSelected = true
    this.isYoutubeSelected = true
    this.maleSelectedClass = 'male-selected'
    this.maleUnselectedClass = 'male-unselected'
    this.femaleSelectedClass = 'female-selected'
    this.femaleUnselectedClass = 'female-unselected'
  }

  getAllCountries () {
    var countries = this.allCountries.map(function (country) {
      return country.text
    })
    return countries
  }

  getAllInterests () {
    var interests = this.interests.map(function (interest) {
      return interest.text
    })
    return interests
  }

  getSelectedCountries () {
    return this.selectedCountries
  }

  addToSelectedCountries (country) {
    var c = this.allCountries.filter(c => c.value === country)
    if (this.selectedCountries.indexOf(c[0]) === -1) {
      this.selectedCountries.push(c[0])
    }
  }

  removeFromSelectedCountries (country) {
    var index = this.selectedCountries.indexOf(country)
    this.selectedCountries.splice(index, 1)
  }

  updateDataArrays (value, status, type) {
    var dataArray = []
    switch (type) {
      case 'age-range':
        dataArray = this.selectedAgeRanges
        break
      case 'gender':
        dataArray = this.selectedGenders
        break
      case 'social-platform':
        dataArray = this.selectedPlatforms
        break
    }
    if (status) {
      if (dataArray.indexOf(value) === -1) {
        dataArray.push(value)
      }
    } else {
      var index = dataArray.indexOf(value)
      dataArray.splice(index, 1)
    }
  }

  clear () {
    this.selectedCountries = []
    this.selectedAgeRanges = []
    this.selectedPlatforms = []
    this.selectedGenders = []
    this.is1317Selected = false
    this.is1824Selected = false
    this.is2534Selected = false
    this.is3544Selected = false
    this.is4554Selected = false
    this.is5564Selected = false
    this.isAbove65Selected = false
    this.isMaleSelected = false
    this.isFemaleSelected = false
    this.isFacebookSelected = false
    this.isInstagramSelected = false
    this.isYoutubeSelected = false
    this.selectedCountry = 'lebanon'
    this.selectedInterest = '6002867432822'
  }

  buildURI (orderBy, pageCount) {
    var countries = null
    if (this.selectedCountries.indexOf('MENA region') > -1) {
      countries = this.allCountries.map(function (a) { return a.value })
    } else {
      countries = this.selectedCountries.map(function (a) { return a })
    }

    var interestObj = this.interests.filter(interest => interest.text === this.selectedInterest)
    var interest = null
    if (interestObj.length > 0) {
      interest = interestObj[0].value
    }

    var request = {}
    request['genders'] = this.selectedGenders
    request['interests'] = [interest]
    request['age_groups'] = this.selectedAgeRanges
    request['countries'] = countries
    request['sort_by'] = [orderBy]
    request['page'] = pageCount
    request['limit'] = 20

    return JSON.stringify(request)
  }
}
