import api from '@/api'

const state = {
  talents: [],
  status: {
    loading: false,
    success: false,
    error: false
  },
  total: 0
}

const mutations = {
  SET_TALENTS (state, payload) {
    state.talents = payload
  },
  SET_TOTAL (state, payload) {
    state.total = payload.length
  },
  CLEAR_TALENTS (state) {
    state.talents = []
    state.total = 0
  },
  LOADING (state) {
    state.status = {
      loading: true,
      success: false,
      error: false
    }
  },
  SUCCESS (state) {
    state.status = {
      loading: false,
      success: true,
      error: false
    }
  },
  ERROR (state, payload) {
    state.status = {
      loading: false,
      success: false,
      error: payload
    }
  },
  CLEAR_ERROR (state) {
    state.status = {
      loading: false,
      success: false,
      error: false
    }
  }
}

const actions = {
  getTalents ({commit}, payload) {
    console.log('getTalents')
    commit('LOADING')
    return api.postWithoutToken('/rank', payload.segment.buildURI(payload.orderBy, payload.pageCount))
    .then((response) => {
      var payload = response.data.data
      commit('SUCCESS')
      commit('SET_TALENTS', payload)
      commit('SET_TOTAL', payload)
    })
    .catch((error) => {
      commit('ERROR', error)
    })
  },
  clearTalents ({commit}) {
    commit('CLEAR_TALENTS')
  }
}

const getters = {
  talents: (state) => state.talents,
  talentsStatus: (state) => state.status,
  total: (state) => state.total
}

export default {
  state,
  actions,
  mutations,
  getters,
  namespaced: true
}
