import api from '@/api'

const state = {
  audienceGrowthData: [],
  audienceFinalScores: [],
  audienceBreakdownsByAge: [],
  audienceBreakdownsByGender: [],
  audienceBreakdownsByInterest: [],
  audienceBreakdownsByGeography: [],
  interestBreakdownsByAge: [],
  interestBreakdownsByGender: [],
  interestBreakdownsByGeography: [],
  finalScoresData: {},

  talentAudienceGrowthDataError: false,
  talentAudienceAgeDataError: false,
  talentAudienceGenderDataError: false,
  talentAudienceGeographyDataError: false,
  talentAudienceInterestDataError: false,
  interestAgeBreakdownError: false,
  interestGenderBreakdownError: false,
  interestGeographyBreakdownError: false,

  status: {
    loading: false,
    success: false,
    error: false
  }
}

const mutations = {
  SET_AUDIENCE_FINAL_SCORES (state, payload) {
    state.audienceFinalScores = payload
  },
  SET_AUDIENCE_GROWTH (state, payload) {
    state.audienceGrowthData = payload
  },
  SET_AUDIENCE_BY_AGE (state, payload) {
    state.audienceBreakdownsByAge = payload
  },
  SET_AUDIENCE_BY_GENDER (state, payload) {
    state.audienceBreakdownsByGender = payload
  },
  SET_AUDIENCE_BY_GEOGRAPHY (state, payload) {
    state.audienceBreakdownsByGeography = payload
  },
  SET_AUDIENCE_BY_INTEREST (state, payload) {
    state.audienceBreakdownsByInterest = payload
  },

  SET_INTEREST_BY_AGE (state, payload) {
    state.interestBreakdownsByAge = payload
  },
  SET_INTEREST_BY_GENDER (state, payload) {
    state.interestBreakdownsByGender = payload
  },
  SET_INTEREST_BY_GEOGRAPHY (state, payload) {
    state.interestBreakdownsByGeography = payload
  },

  SET_AUDIENCE_GROWTH_ERROR (state, payload) {
    state.talentAudienceGrowthDataError = payload
  },
  SET_AUDIENCE_BY_AGE_ERROR (state, payload) {
    state.talentAudienceAgeDataError = payload
  },
  SET_AUDIENCE_BY_GENDER_ERROR (state, payload) {
    state.talentAudienceGenderDataError = payload
  },
  SET_AUDIENCE_BY_GEOGRAPHY_ERROR (state, payload) {
    state.talentAudienceGeographyDataError = payload
  },
  SET_AUDIENCE_BY_INTEREST_ERROR (state, payload) {
    state.talentAudienceInterestDataError = payload
  },

  SET_INTEREST_BY_AGE_ERROR (state, payload) {
    state.interestAgeBreakdownError = payload
  },
  SET_INTEREST_BY_GENDER_ERROR (state, payload) {
    state.interestGenderBreakdownError = payload
  },
  SET_INTEREST_BY_GEOGRAPHY_ERROR (state, payload) {
    state.interestGeographyBreakdownError = payload
  },
  RESET_STATE (state) {
    state.audienceGrowthData = []
    state.audienceFinalScores = []
    state.audienceBreakdownsByAge = []
    state.audienceBreakdownsByGender = []
    state.audienceBreakdownsByInterest = []
    state.audienceBreakdownsByGeography = []
    state.interestBreakdownsByAge = []
    state.interestBreakdownsByGender = []
    state.interestBreakdownsByGeography = []
    state.finalScoresData = {}

    state.talentAudienceGrowthDataError = false
    state.talentAudienceAgeDataError = false
    state.talentAudienceGenderDataError = false
    state.talentAudienceGeographyDataError = false
    state.talentAudienceInterestDataError = false
    state.interestAgeBreakdownError = false
    state.interestGenderBreakdownError = false
    state.interestGeographyBreakdownError = false
  },

  LOADING (state) {
    state.status = {
      loading: true,
      success: false,
      error: false
    }
  },
  SUCCESS (state) {
    state.status = {
      loading: false,
      success: true,
      error: false
    }
  },
  ERROR (state, payload) {
    state.status = {
      loading: false,
      success: false,
      error: payload
    }
  },
  CLEAR_ERROR (state) {
    state.status = {
      loading: false,
      success: false,
      error: false
    }
  }
}

const actions = {
  fetchAudienceScores ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/growth')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_AUDIENCE_GROWTH', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_AUDIENCE_GROWTH_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_AUDIENCE_GROWTH_ERROR', error)
        console.log(error)
      })
  },
  fetchAudienceFinalScores ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/totals')
      .then((response) => {
        if (response.data) {
          commit('SET_AUDIENCE_FINAL_SCORES', response.data.data)
          commit('SUCCESS')
        }
      })
      .catch(function (error) {
        commit('ERROR')
        console.log(error)
      })
  },

  fetchAudienceBreakdownsByAge ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/breakdowns/age')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_AUDIENCE_BY_AGE', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_AUDIENCE_BY_AGE_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_AUDIENCE_BY_AGE_ERROR', error)
        console.log(error)
      })
  },
  fetchAudienceBreakdownsByGender ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/breakdowns/gender')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_AUDIENCE_BY_GENDER', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_AUDIENCE_BY_GENDER_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_AUDIENCE_BY_GENDER_ERROR', error)
        console.log(error)
      })
  },
  fetchAudienceBreakdownsByGeography ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/breakdowns/geography')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_AUDIENCE_BY_GEOGRAPHY', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_AUDIENCE_BY_GEOGRAPHY_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_AUDIENCE_BY_GEOGRAPHY_ERROR', error)
        console.log(error)
      })
  },
  fetchAudienceBreakdownsByInterest ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/breakdowns/interest')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_AUDIENCE_BY_INTEREST', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_AUDIENCE_BY_INTEREST_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_AUDIENCE_BY_INTEREST_ERROR', error)
        console.log(error)
      })
  },
  fetchInterestBreakdownsByAge ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/breakdowns/interests/' + payload.interestId + '/age')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_INTEREST_BY_AGE', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_INTEREST_BY_AGE_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_INTEREST_BY_AGE_ERROR', error)
        console.log(error)
      })
  },
  fetchInterestBreakdownsByGender ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/breakdowns/interests/' + payload.interestId + '/gender')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_INTEREST_BY_GENDER', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_INTEREST_BY_GENDER_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_INTEREST_BY_GENDER_ERROR', error)
        console.log(error)
      })
  },
  fetchInterestBreakdownsByGeography ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/audience/breakdowns/interests/' + payload.interestId + '/geography')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_INTEREST_BY_GEOGRAPHY', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_INTEREST_BY_GEOGRAPHY_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_INTEREST_BY_GEOGRAPHY_ERROR', error)
        console.log(error)
      })
  },
  clearState ({commit}) {
    commit('RESET_STATE')
    commit('CLEAR_ERROR')
  }
}

const getters = {
  audienceGrowthData: (state) => state.audienceGrowthData,
  audienceFinalScores: (state) => state.audienceFinalScores,
  audienceBreakdownsByAge: (state) => state.audienceBreakdownsByAge,
  audienceBreakdownsByGender: (state) => state.audienceBreakdownsByGender,
  audienceBreakdownsByInterest: (state) => state.audienceBreakdownsByInterest,
  audienceBreakdownsByGeography: (state) => state.audienceBreakdownsByGeography,
  interestBreakdownsByAge: (state) => state.interestBreakdownsByAge,
  interestBreakdownsByGender: (state) => state.interestBreakdownsByGender,
  interestBreakdownsByGeography: (state) => state.interestBreakdownsByGeography,

  talentAudienceGrowthDataError: (state) => state.talentAudienceGrowthDataError,
  talentAudienceAgeDataError: (state) => state.talentAudienceAgeDataError,
  talentAudienceGenderDataError: (state) => state.talentAudienceGenderDataError,
  talentAudienceGeographyDataError: (state) => state.talentAudienceGeographyDataError,
  talentAudienceInterestDataError: (state) => state.talentAudienceInterestDataError,
  interestAgeBreakdownError: (state) => state.interestAgeBreakdownError,
  interestGenderBreakdownError: (state) => state.interestGenderBreakdownError,
  interestGeographyBreakdownError: (state) => state.interestGeographyBreakdownError
}

export default {
  namespaced: true,
  state,
  actions,
  mutations,
  getters
}
