import api from '@/api'

const state = {
  TotalVideoViews: [],
  TotalChannelViews: [],
  TotalWatchTime: [],
  TotalWatchTimeGrowth: [],
  ContentFinalScores: [],
  EngagementReachScores: {},
  EngagementReachGrowth: [],
  TotalReachScores: null,
  TotalReachGrowthScores: [],
  PostingFrequencyScores: [],
  PostingFrequencyCurrentScores: {},

  TalentContentTotalVideoViewsDataError: false,
  TalentContentEngagementReachDataError: false,
  TalentContentTotalReachGrowthDataError: false,
  TalentContentTotalReachDataError: false,
  TalentContentPostingFrequencyDataError: false,
  TalentContentPostingFrequencyCurrentDataError: false,
  EngagementReachGrowthDataError: false,
  TalentContentTotalChannelViewsDataError: false,
  TalentContentTotalWatchTimeGrowthDataError: false,
  TalentContentTotalWatchTimeDataError: false,

  status: {
    loading: false,
    success: false,
    error: false
  }
}

const mutations = {
  SET_TOTAL_VIDEO_VIEWS (state, payload) {
    state.TotalVideoViews = payload
  },
  SET_TOTAL_CHANNEL_VIEWS (state, payload) {
    state.TotalChannelViews = payload
  },
  SET_TOTAL_WATCH_TIME (state, payload) {
    state.TotalWatchTime = payload
  },
  SET_TOTAL_WATCH_TIME_GROWTH (state, payload) {
    state.TotalWatchTimeGrowth = payload
  },
  SET_CONTENT_FINAL_SCORES (state, payload) {
    state.ContentFinalScores = payload
  },
  SET_ENGAGEMENT_REACH_SCORES (state, payload) {
    state.EngagementReachScores = payload
  },
  SET_ENGAGEMENT_REACH_GROWTH (state, payload) {
    state.EngagementReachGrowth = payload
  },
  SET_TOTAL_REACH_SCORES (state, payload) {
    state.TotalReachScores = payload
  },
  SET_TOTAL_REACH_GROWTH (state, payload) {
    state.TotalReachGrowthScores = payload
  },
  SET_POSTING_FREQUENCY_SCORES (state, payload) {
    state.PostingFrequencyScores = payload
  },
  SET_POSTING_FREQUENCY_CURRENT_SCORES (state, payload) {
    state.PostingFrequencyCurrentScores = payload
  },

  SET_TOTAL_VIDEO_VIEWS_ERROR (state, payload) {
    state.TalentContentTotalVideoViewsDataError = payload
  },
  SET_TOTAL_CHANNEL_VIEWS_ERROR (state, payload) {
    state.TalentContentTotalChannelViewsDataError = payload
  },
  SET_TOTAL_WATCH_TIME_ERROR (state, payload) {
    state.TalentContentTotalWatchTimeDataError = payload
  },
  SET_TOTAL_WATCH_TIME_GROWTH_ERROR (state, payload) {
    state.TalentContentTotalWatchTimeGrowthDataError = payload
  },
  SET_CONTENT_FINAL_SCORES_ERROR (state, payload) {
    state.ContentFinalScoresDataError = payload
  },
  SET_ENGAGEMENT_REACH_SCORES_ERROR (state, payload) {
    state.TalentContentEngagementReachDataError = payload
  },
  SET_ENGAGEMENT_REACH_GROWTH_ERROR (state, payload) {
    state.EngagementReachGrowthDataError = payload
  },
  SET_TOTAL_REACH_SCORES_ERROR (state, payload) {
    state.TalentContentTotalReachDataError = payload
  },
  SET_TOTAL_REACH_GROWTH_ERROR (state, payload) {
    state.TalentContentTotalReachGrowthDataError = payload
  },
  SET_POSTING_FREQUENCY_SCORES_ERROR (state, payload) {
    state.TalentContentPostingFrequencyDataError = payload
  },
  SET_POSTING_FREQUENCY_CURRENT_SCORES_ERROR (state, payload) {
    state.TalentContentPostingFrequencyCurrentDataError = payload
  },
  RESET_STATE (state) {
    state.TotalVideoViews = []
    state.TotalChannelViews = []
    state.TotalWatchTime = []
    state.TotalWatchTimeGrowth = []
    state.ContentFinalScores = []
    state.EngagementReachScores = {}
    state.EngagementReachGrowth = []
    state.TotalReachScores = null
    state.TotalReachGrowthScores = []
    state.PostingFrequencyScores = []
    state.PostingFrequencyCurrentScores = {}

    state.TalentContentTotalVideoViewsDataError = false
    state.TalentContentEngagementReachDataError = false
    state.TalentContentTotalReachGrowthDataError = false
    state.TalentContentTotalReachDataError = false
    state.TalentContentPostingFrequencyDataError = false
    state.TalentContentPostingFrequencyCurrentDataError = false
    state.EngagementReachGrowthDataError = false
    state.TalentContentTotalChannelViewsDataError = false
    state.TalentContentTotalWatchTimeGrowthDataError = false
    state.TalentContentTotalWatchTimeDataError = false
  },

  LOADING (state) {
    state.status = {
      loading: true,
      success: false,
      error: false
    }
  },
  SUCCESS (state) {
    state.status = {
      loading: false,
      success: true,
      error: false
    }
  },
  ERROR (state, payload) {
    state.status = {
      loading: false,
      success: false,
      error: payload
    }
  },
  CLEAR_ERROR (state) {
    state.status = {
      loading: false,
      success: false,
      error: false
    }
  }
}

const actions = {
  fetchTotalVideoViews ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/metrics/videos/growth')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_TOTAL_VIDEO_VIEWS', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_TOTAL_VIDEO_VIEWS_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_TOTAL_VIDEO_VIEWS_ERROR', error)
        console.log(error)
      })
  },
  fetchContentFinalScores ({commit}, payload) {
    commit('LOADING')

    var target = ''
    if (payload.platform !== 'youtube') {
      target = 'videos'
    } else {
      target = 'channel'
    }

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/metrics/' + target)
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_CONTENT_FINAL_SCORES', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_CONTENT_FINAL_SCORES_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_CONTENT_FINAL_SCORES_ERROR', error)
        console.log(error)
      })
  },
  fetchFacebookAverageVideoViews ({commit}, payload) {
    return api.get('/insights/talents/' + payload.talentId + '/facebook/content/metrics/videos')
  },
  fetchInstagramAverageVideoViews ({commit}, payload) {
    return api.get('/insights/talents/' + payload.talentId + '/instagram/content/metrics/videos')
  },
  fetchYoutubeAverageVideoViews ({commit}, payload) {
    return api.get('/insights/talents/' + payload.talentId + '/youtube/content/metrics/channel')
  },
  fetchEngagementReachScores ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/metrics/breakdowns/type')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_ENGAGEMENT_REACH_SCORES', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_ENGAGEMENT_REACH_SCORES_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_ENGAGEMENT_REACH_SCORES_ERROR', error)
        console.log(error)
      })
  },
  fetchEngagementReachGrowth ({commit}, payload, postType, engagementType) {
    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/' + payload.postType + '/metrics/' + payload.engagementType + '/growth')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_ENGAGEMENT_REACH_GROWTH', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_ENGAGEMENT_REACH_GROWTH_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_ENGAGEMENT_REACH_GROWTH_ERROR', error)
        console.log(error)
      })
  },
  fetchTotalReachScoresGrowth ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/reach/growth')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_TOTAL_REACH_GROWTH', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_TOTAL_REACH_GROWTH_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_TOTAL_REACH_GROWTH_ERROR', error)
        console.log(error)
      })
  },
  fetchTotalReachScores ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/reach')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_TOTAL_REACH_SCORES', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_TOTAL_REACH_SCORES_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_TOTAL_REACH_SCORES_ERROR', error)
        console.log(error)
      })
  },
  fetchPostingFrequencyScores ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/posting-frequency/growth')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_POSTING_FREQUENCY_SCORES', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_POSTING_FREQUENCY_SCORES_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_POSTING_FREQUENCY_SCORES_ERROR', error)
        console.log(error)
      })
  },
  fetchPostingFrequencyCurrentScores ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/posting-frequency')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_POSTING_FREQUENCY_CURRENT_SCORES', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_POSTING_FREQUENCY_CURRENT_SCORES_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_POSTING_FREQUENCY_CURRENT_SCORES_ERROR', error)
        console.log(error)
      })
  },
  fetchTotalChannelViewsGrowth ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/metrics/channel/growth')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_TOTAL_CHANNEL_VIEWS', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_TOTAL_CHANNEL_VIEWS_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_TOTAL_CHANNEL_VIEWS_ERROR', error)
        console.log(error)
      })
  },
  fetchTotalWatchTimeGrowth ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/watch-time/growth')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_TOTAL_WATCH_TIME_GROWTH', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_TOTAL_WATCH_TIME_GROWTH_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_TOTAL_WATCH_TIME_GROWTH_ERROR', error)
        console.log(error)
      })
  },
  fetchTotalWatchTime ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/watch-time')
      .then((response) => {
        if (response.data) {
          if (response.data.data) {
            commit('SET_TOTAL_WATCH_TIME', response.data.data)
            commit('SUCCESS')
          } else {
            commit('SET_TOTAL_WATCH_TIME_ERROR', true)
          }
        }
      })
      .catch(function (error) {
        commit('SET_TOTAL_WATCH_TIME_ERROR', error)
        console.log(error)
      })
  },
  clearState ({commit}) {
    commit('RESET_STATE')
    commit('CLEAR_ERROR')
  }
}

const getters = {
  TotalVideoViews: (state) => state.TotalVideoViews,
  TotalChannelViews: (state) => state.TotalChannelViews,
  TotalWatchTime: (state) => state.TotalWatchTime,
  TotalWatchTimeGrowth: (state) => state.TotalWatchTimeGrowth,
  ContentFinalScores: (state) => state.ContentFinalScores,
  EngagementReachScores: (state) => state.EngagementReachScores,
  EngagementReachGrowth: (state) => state.EngagementReachGrowth,
  TotalReachScores: (state) => state.TotalReachScores,
  TotalReachGrowthScores: (state) => state.TotalReachGrowthScores,
  PostingFrequencyScores: (state) => state.PostingFrequencyScores,
  PostingFrequencyCurrentScores: (state) => state.PostingFrequencyCurrentScores,

  TalentContentTotalVideoViewsDataError: (state) => state.TalentContentTotalVideoViewsDataError,
  TalentContentEngagementReachDataError: (state) => state.TalentContentEngagementReachDataError,
  TalentContentTotalReachGrowthDataError: (state) => state.TalentContentTotalReachGrowthDataError,
  TalentContentTotalReachDataError: (state) => state.TalentContentTotalReachDataError,
  TalentContentPostingFrequencyDataError: (state) => state.TalentContentPostingFrequencyDataError,
  TalentContentPostingFrequencyCurrentDataError: (state) => state.TalentContentPostingFrequencyCurrentDataError,
  EngagementReachGrowthDataError: (state) => state.EngagementReachGrowthDataError,
  TalentContentTotalChannelViewsDataError: (state) => state.TalentContentTotalChannelViewsDataError,
  TalentContentTotalWatchTimeGrowthDataError: (state) => state.TalentContentTotalWatchTimeGrowthDataError,
  TalentContentTotalWatchTimeDataError: (state) => state.TalentContentTotalWatchTimeDataError,

  status: (state) => state.status

}

export default {
  namespaced: true,
  state,
  actions,
  mutations,
  getters
}
