import api from '@/api'

const state = {
  contentScores: [],
  contentScoresGrowth: [],
  platform: null,
  ContentScoresGrowthDataError: false,
  status: {
    loading: false,
    success: false,
    error: false
  }
}

const mutations = {
  SET_CONTENT_SCORES (state, payload) {
    state.contentScores = payload
  },
  SET_CONTENT_SCORES_GROWTH (state, payload) {
    state.contentScoresGrowth = payload
  },
  SET_CONTENT_SCORES_GROWTH_ERROR (state, payload) {
    state.ContentScoresGrowthDataError = payload
  },
  SET_PLATFORM (state, payload) {
    state.platform = payload
  },
  RESET_STATE (state) {
    state.contentScores = []
    state.contentScoresGrowth = []
    state.ContentScoresGrowthDataError = false
    state.platform = null
  },

  LOADING (state) {
    state.status = {
      loading: true,
      success: false,
      error: false
    }
  },
  SUCCESS (state) {
    state.status = {
      loading: false,
      success: true,
      error: false
    }
  },
  ERROR (state, payload) {
    state.status = {
      loading: false,
      success: false,
      error: payload
    }
  },
  CLEAR_ERROR (state) {
    state.status = {
      loading: false,
      success: false,
      error: false
    }
  }
}

const actions = {
  getContentScores ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/scores')
    .then((response) => {
      if (response.data) {
        if (response.data.data) {
          commit('SET_CONTENT_SCORES', response.data.data)
          commit('SUCCESS')
        } else {
          commit('SET_CONTENT_SCORES_GROWTH_ERROR', 'nodata')
        }
      }
    })
    .catch(function (error) {
      commit('ERROR', error)
      console.log(error)
    })
  },
  fetchContentScoreGrowth ({commit}, payload) {
    commit('LOADING')

    return api.get('/insights/talents/' + payload.talentId + '/' + payload.platform + '/content/scores/growth')
    .then((response) => {
      if (response.data) {
        if (response.data.data) {
          commit('SET_CONTENT_SCORES_GROWTH', response.data.data)
          commit('SUCCESS')
        } else {
          commit('SET_CONTENT_SCORES_GROWTH_ERROR', true)
        }
      }
    })
    .catch(function (error) {
      commit('ERROR')
      console.log(error)
    })
  },
  setPlatform ({commit}, payload) {
    commit('SET_PLATFORM', payload.platform)
  },
  clearState ({commit}) {
    commit('RESET_STATE')
    commit('CLEAR_ERROR')
  }
}

const getters = {
  contentScores: (state) => state.contentScores,
  platform: (state) => state.platform,
  contentScoresGrowth: (state) => state.contentScoresGrowth,
  ContentScoresGrowthDataError: (state) => state.ContentScoresGrowthDataError
}

export default {
  namespaced: true,
  state,
  actions,
  mutations,
  getters
}
