import api from '@/api'

const state = {
  talent: null,
  talentsList: [],
  status: {
    loading: false,
    success: false,
    error: false,
    loadMore: false
  },
  total: 0,
  maritalStatus: '',
  countries: '',
  categories: []
}

const mutations = {
  SET_TALENTS (state, payload) {
    state.talentsList = payload
  },
  CLEAR_TALENTS (state) {
    state.talentsList = []
    state.total = 0
  },
  SET_TOTAL (state, payload) {
    state.total = payload
  },
  SET_TALENT (state, payload) {
    state.talent = payload
  },
  SET_MARITAL_STATUS (state, payload) {
    state.maritalStatus = payload
  },
  SET_COUNTRIES (state, payload) {
    state.countries = payload
  },
  SET_CATEGORIES (state, payload) {
    state.categories = payload
  },
  LOADING (state) {
    state.status = {
      loading: true,
      success: false,
      error: false
    }
  },
  SUCCESS (state) {
    state.status = {
      loading: false,
      success: true,
      error: false
    }
  },
  ERROR (state, payload) {
    state.status = {
      loading: false,
      success: false,
      error: payload
    }
  },
  CLEAR_ERROR (state) {
    state.status = {
      loading: false,
      success: false,
      error: false
    }
  },
  LOAD_MORE (state) {
    state.talentStatus = {
      loading: false,
      success: true,
      error: false,
      loadMore: true
    }
  }
}

const actions = {
  getTalents ({commit}, payload) {
    commit('LOADING')
    return api.get('/talents?limit=' + payload.limit)
    .then((response) => {
      var payload = response.data.data
      commit('SUCCESS')
      commit('SET_TALENTS', payload)
      commit('SET_TOTAL', response.data.total)
    })
    .catch((error) => {
      console.log(error)
      commit('ERROR', error)
    })
  },
  searchTalents ({commit}, payload) {
    commit('CLEAR_TALENTS')
    commit('LOADING')
    return api.get('/search/talents?input=' + payload.keyword +
      '&limit=' + payload.limit + '&sort_by=asc')
      .then((response) => {
        commit('SUCCESS')
        var result = response.data.data
        commit('SET_TALENTS', result)
        commit('SET_TOTAL', response.data.total)
      })
      .catch((error) => {
        console.log(error)
        commit('ERROR', error)
      })
  },
  clearTalents ({commit}) {
    commit('CLEAR_TALENTS')
  },
  clearError ({commit}) {
    commit('CLEAR_ERROR')
  },
  updateTalentStatus ({commit}, payload) { // talentId, status, token, note, reason
    commit('LOADING')
    return api.put('/admins/talents/' + payload.talentId + '/registration', {
      registration_status: payload.status,
      note: payload.note,
      reason: payload.reason
    })
      .then((response) => {
        if (response.data) {
          var talentIndex = state.talentsList.findIndex(talent => talent.id === payload.talentId)
          state.talentsList.splice(talentIndex, 1)
          commit('SUCCESS')
          commit('SET_TALENTS', state.talentsList)
          commit('SET_TOTAL', state.total - 1)
        }
      })
      .catch(function (error) {
        commit('ERROR', error)
      })
  },
  fetchTalent ({commit}, payload) {
    commit('LOADING')
    return api.get('/talents/' + payload.talentId)
      .then((response) => {
        if (response) {
          commit('SET_TALENT', response.data.data)
          commit('SUCCESS')
        }
      })
      .catch((error) => {
        console.log(error)
        commit('ERROR', error)
      }
    )
  },
  createTalent ({commit}, payload) {
    commit('LOADING')
    console.log(payload)
    return api.post('/admins/talents', payload)
    .then((response) => {
      console.log(response)
      if (response.data) {
        commit('SET_TALENT', response.data.data)
        commit('SUCCESS')
      }
    })
    .catch(function (error) {
      commit('ERROR', error)
      console.log(error)
    })
  },
  updateTalent ({commit}, payload) {
    console.log(payload.data)
    commit('LOADING')
    return api.put('/talents/' + payload.talentId, payload)
      .then((response) => {
        if (response.data) {
          commit('SET_TALENT', response.data.data)
          commit('SUCCESS')
        }
      })
      .catch(function (error) {
        commit('ERROR', error)
      })
  },
  updateTalentSocialAccountStatus ({commit}, payload) { // talentId, status, token, platform, note, reason
    commit('LOADING')
    return api.put('/admins/talents/' + payload.talentId + '/social-accounts/' + payload.platform + '/status', {
      status: payload.status,
      note: payload.note,
      reason: payload.reason
    })
      .then((response) => {
        if (response.data) {
          var talentIndex = state.talentsList.findIndex(talent => talent.id === payload.talentId)
          state.talentsList.splice(talentIndex, 1)
          commit('SET_TALENTS', state.talentsList)
          commit('SET_TOTAL', state.total - 1)
        }
      })
      .catch(function (error) {
        commit('ERROR', error)
        console.log(error)
      })
  },

  updateTalentEmail ({commit}, payload) {
    commit('LOADING')
    return api.put('/admins/talents/' + payload.talentId + '/email', payload)
      .then((response) => {
        if (response.data) {
          commit('SUCCESS')
        }
      })
      .catch(function (error) {
        commit('ERROR', error)
        console.log(error)
      })
  },
  disconnectTalentPlatform ({commit}, payload) {
    commit('LOADING')
    return api.delete('talents/' + payload.talentId + '/social-accounts/disconnect/' + payload.platform)
    .then((response) => {
      commit('SUCCESS')
    })
    .catch(function (error) {
      commit('ERROR', error)
      console.log(error)
    })
  },
  fetchMaritalStatus ({commit}) {
    commit('LOADING')
    return api.get('/status/marital')
      .then((response) => {
        if (response.data) {
          commit('SET_MARITAL_STATUS', response.data.data)
          commit('SUCCESS')
        }
      })
      .catch(function (error) {
        commit('ERROR', error)
      })
  },
  fetchTalentsWithStatus ({commit}, payload) {
    var socialAccountStatusParameter = ''
    if (payload.socialAccountStatus) {
      socialAccountStatusParameter = '&social_account_status=' + payload.socialAccountStatus
    }
    var socialAccountAccessParameter = ''
    if (payload.socialAccountAccess !== null) {
      socialAccountAccessParameter = '&social_account_access=' + payload.socialAccountAccess
    }
    if (payload.loadMore === null || payload.loadMore === undefined) {
      commit('LOADING')
      commit('CLEAR_TALENTS')
    } else {
      commit('LOAD_MORE')
    }
    return api.get('/admins/talents?registration_status=' + payload.status + '&order_by=' + payload.orderBy + '&sort_by=desc&with_hidden=true' + socialAccountStatusParameter + socialAccountAccessParameter + '&limit=' + payload.limit)
      .then((response) => {
        if (response.data) {
          commit('SET_TALENTS', response.data.data)
          commit('SET_TOTAL', response.data.total)
        }
        commit('SUCCESS')
      })
      .catch(function (error) {
        commit('ERROR', error)
        console.log(error)
      })
  },
  fetchCountries ({commit}) {
    commit('LOADING')
    return api.get('/countries')
      .then((response) => {
        if (response.data) {
          commit('SET_COUNTRIES', response.data.data)
          commit('SUCCESS')
        }
      })
      .catch(function (error) {
        commit('ERROR', error)
        console.log(error)
      })
  },
  fetchCategories ({commit}) {
    commit('LOADING')
    return api.get('/talents/categories')
    .then((response) => {
      if (response.data) {
        commit('SET_CATEGORIES', response.data.data)
        commit('SUCCESS')
      }
    })
    .catch(function (error) {
      commit('ERROR', error)
      console.log(error)
    })
  },
  showSuccess ({commit}) {
    commit('SUCCESS')
  },
  setTalentDetails ({commit}, payload) {

  }
}

const getters = {
  talents: (state) => state.talentsList,
  talent: (state) => state.talent,
  talentStatus: (state) => state.status,
  total: (state) => state.total,
  maritalStatus: (state) => state.maritalStatus,
  countries: (state) => state.countries,
  categories: (state) => state.categories
}

export default {
  namespaced: true,
  state,
  actions,
  mutations,
  getters
}
